import React, { useState } from "react";
import {
  FaMicrophone,
  FaVideo,
  FaPhoneSlash,
  FaMicrophoneSlash,
  FaVideoSlash,
} from "react-icons/fa";
import { BsThreeDotsVertical } from "react-icons/bs";
import "./WebRTCFooter.css";
import Dropdown from "../Dropdown/index";
import ListItem from "../ListItem/index";
import AudioModal from "../AudioModal/AudioModal";
import VideoModal from "../VideoModal/VideoModal";

const WebRTCFooter = ({
  isConnected,
  isMuted,
  isVideoEnabled,
  handleToggleMute,
  handleToggleVideo,
  handleStartCall,
  handleEndCall,
  audioInputs,
  videoInputs,
  handleToggleAudioSource,
  handleToggleVideoSource,
}) => {
  const [showDropdown, setShowDropdown] = useState(false);

  const [isAudioModalOpen, setAudioModalOpen] = React.useState(false);
  const [isVideoModalOpen, setVideoModalOpen] = React.useState(false);

  const renderButtons = () => {
    if (!isConnected) return null;

    return (
      <>
        <div className="webrtc-footer__button" onClick={handleEndCall}><FaPhoneSlash /></div>
        <div className="webrtc-footer__button" onClick={handleToggleMute}>
          {isMuted ? <FaMicrophoneSlash /> : <FaMicrophone />}
        </div>
        <div className="webrtc-footer__button" onClick={handleToggleVideo}>
          {isVideoEnabled ? <FaVideo /> : <FaVideoSlash />}
        </div>
        <div
          className="webrtc-footer__button"
          onClick={() => setShowDropdown(!showDropdown)}
        >
          <Dropdown show={showDropdown}>
            <ListItem
              title="Video Source"
              icon={<FaVideo />}
              onClick={() => setVideoModalOpen(true)}
            />
            <ListItem
              title="Audio Source"
              icon={<FaMicrophone />}
              onClick={() => setAudioModalOpen(true)}
            />
          </Dropdown>
          <BsThreeDotsVertical />
        </div>
      </>
    )
  }

  return (
    <footer className="webrtc-footer">
      {renderButtons()}
      <VideoModal
        isOpen={isVideoModalOpen}
        handleToggleSource={handleToggleVideoSource}
        data={videoInputs}
        onClose={() => setVideoModalOpen(false)}
      />
      <AudioModal
        data={audioInputs}
        handleToggleSource={handleToggleAudioSource}
        isOpen={isAudioModalOpen}
        onClose={() => setAudioModalOpen(false)}
      />
    </footer>
  );
};

export default WebRTCFooter;
